==> public-sdk-2.0.22-sources.jar: com/voxeet/sdk/core/services/TimeoutRunnable.java <==
package com.voxeet.sdk.core.services;

import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import com.voxeet.sdk.core.abs.ConferenceService;
import com.voxeet.sdk.events.ConferenceTimeoutUserJoinedEvent;

import org.greenrobot.eventbus.EventBus;

import eu.codlab.simplepromise.solve.ErrorPromise;
import eu.codlab.simplepromise.solve.PromiseExec;
import eu.codlab.simplepromise.solve.Solver;

public class TimeoutRunnable implements Runnable {

    private static final String TAG = TimeoutRunnable.class.getSimpleName();

    private long mTimeout;
    private @NonNull
    EventBus mEventBus; //initialized with parametered-constructor
    ConferenceService mService; //initialized with parametered-constructor
    private boolean mCanceled;
    private boolean mTriggered;

    /**
     * Default constructor, make the runnable "not canceled" by default
     * and triggered is false
     */
    private TimeoutRunnable() {
        setCanceled(false);
        mTriggered = false;
    }

    /**
     * @param service   the service which will be called back
     * @param event_bus the configured event bus
     * @param timeout   the current timeout
     */
    public TimeoutRunnable(@NonNull ConferenceService service,
                           @NonNull EventBus event_bus,
                           long timeout) {
        this();

        mService = service;
        mEventBus = event_bus;
        mTimeout = timeout;
    }

    public void setCanceled(boolean canceled) {
        mCanceled = canceled;
    }

    public boolean isCanceled() {
        return mCanceled;
    }

    @Override
    public void run() {

        if (!isCanceled()) {
            mService.leave()
                    .then(new PromiseExec() {
                        @Override
                        public void onCall(@Nullable Object o, @NonNull Solver solver) {

                        }
                    })
                    .error(new ErrorPromise() {
                        @Override
                        public void onError(Throwable error) {
                            error.printStackTrace();
                        }
                    });

            //conference was left after Xms
            //note that if you change the timeout after calling the join, the
            //value returned is absolutely inaccurate
            mEventBus.post(new ConferenceTimeoutUserJoinedEvent(mTimeout));
            mTriggered = true;
        }
    }

    public boolean isTriggered() {
        return mTriggered;
    }
}

==> public-sdk-2.0.68-sources.jar: com/voxeet/sdk/core/services/TimeoutRunnable.java <==
package com.voxeet.sdk.core.services;

import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import com.voxeet.sdk.events.sdk.ConferenceTimeoutUserJoinedEvent;

import org.greenrobot.eventbus.EventBus;

import eu.codlab.simplepromise.solve.ErrorPromise;
import eu.codlab.simplepromise.solve.PromiseExec;
import eu.codlab.simplepromise.solve.Solver;

public class TimeoutRunnable implements Runnable {

    @NonNull
    private EventBus mEventBus; //initialized with parametered-constructor

    @NonNull
    ConferenceService mService; //initialized with parametered-constructor

    private long mTimeout;
    private boolean mCanceled;
    private boolean mTriggered;

    /**
     * Default constructor, make the runnable "not canceled" by default
     * and triggered is false
     */
    private TimeoutRunnable() {
        setCanceled(false);
        mTriggered = false;
    }

    /**
     * @param service   the service which will be called back
     * @param event_bus the configured event bus
     * @param timeout   the current timeout
     */
    TimeoutRunnable(@NonNull ConferenceService service,
                    @NonNull EventBus event_bus,
                    long timeout) {
        this();

        mService = service;
        mEventBus = event_bus;
        mTimeout = timeout;
    }

    void setCanceled(boolean canceled) {
        mCanceled = canceled;
    }

    private boolean isCanceled() {
        return mCanceled;
    }

    @Override
    public void run() {

        if (!isCanceled()) {
            mService.leave()
                    .then(new PromiseExec() {
                        @Override
                        public void onCall(@Nullable Object o, @NonNull Solver solver) {

                        }
                    })
                    .error(new ErrorPromise() {
                        @Override
                        public void onError(Throwable error) {
                            error.printStackTrace();
                        }
                    });

            //conference was left after Xms
            //note that if you change the timeout after calling the join, the
            //value returned is absolutely inaccurate
            mEventBus.post(new ConferenceTimeoutUserJoinedEvent(mTimeout));
            mTriggered = true;
        }
    }

    boolean isTriggered() {
        return mTriggered;
    }
}
